-- tested with postgresql
-- you can add a unique sequence id to the table if you want

drop table linksdb;

create table linksdb (
    urlname        varchar(50) not null,
    recursionlevel int not null,
    parentname     varchar(50),
    baseref        varchar(50),
    errorstring    varchar(50),
    validstring    varchar(50),
    warningstring  varchar(50),
    infostring     varchar(150),
    valid          int,
    url            varchar(50),
    line           int,
    col            int,
    name           varchar(50),
    checktime      int,
    dltime         int,
    dlsize         int,
    cached         int
);
